@@ -14,31 +14,7 @@ WavModelDefinition = ModelDefinition(markdown_filepath='encoders/audio/pytorch/w
 
 class Wav2Vec(BaseAudio2Vec):
     definition = WavModelDefinition
-    def __init__(self, model_url: str = 'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small.pt'):
-        self.list_of_urls = [
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small.pt',
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small_10m.pt',
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small_100h.pt',
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small_960h.pt',
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_vox.pt',
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_vox_10m.pt',
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_vox_100h.pt',
-            'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec2_vox_960h.pt',
-        ]
-        self.validate_model_url(model_url, self.list_of_urls)
-        self.init(model_url)
-        self.vector_length = 512
-
-    def init(self, model_url: str):
-        self.model_url = model_url
-        self.model_name = self.model_url.replace(
-            'https://dl.fbaipublicfiles.com/fairseq/', '').replace('/', '_')
-        torch_model = torch.hub.load_state_dict_from_url(self.model_url)
-        self.model = Wav2VecModel.build_model(torch_model['args'], task=None)
-
-    @property
-    def urls(self):
-        return {
+    urls =  {
             'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small.pt': {},
             'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small_10m.pt': {},
             'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small_100h.pt': {},
@@ -48,6 +24,17 @@ class Wav2Vec(BaseAudio2Vec):
             'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_vox_100h.pt': {},
             'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec2_vox_960h.pt': {},
         }
+    def __init__(self, model_url: str = 'https://dl.fbaipublicfiles.com/fairseq/wav2vec/wav2vec_small.pt'):
+        self.validate_model_url(model_url, self.urls)
+        self.init(model_url)
+        self.vector_length = 512
+
+    def init(self, model_url: str):
+        self.model_url = model_url
+        self.model_name = self.model_url.replace(
+            'https://dl.fbaipublicfiles.com/fairseq/', '').replace('/', '_')
+        torch_model = torch.hub.load_state_dict_from_url(self.model_url)
+        self.model = Wav2VecModel.build_model(torch_model['args'], task=None)
 
     @catch_vector_errors
     def encode(self, audio, vector_operation='mean'):
